"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTilt = useTilt;
var _react = require("react");
var _reactNative = require("react-native");
const LINKING_ERROR = `The package 'react-native-tilt-ble' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';
const Tilt = _reactNative.NativeModules.Tilt ? _reactNative.NativeModules.Tilt : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
function useTilt() {
  const [temperature, setTemperature] = (0, _react.useState)(null);
  const [gravity, setGravity] = (0, _react.useState)(null);
  const [device, setDevice] = (0, _react.useState)(null);
  const [scanning, setScanning] = (0, _react.useState)(false);
  const startScan = async cb => {
    const allowed = await requestPermissions();
    if (allowed) {
      console.log('Scanning...');
      setScanning(true);
      Tilt.startScanning(() => {}, error => {
        setScanning(false);
        console.error('Scan error:', error);
        if (cb) {
          cb('Scan error: ' + error);
        }
      });
    } else {
      console.error('Missing permissions');
      if (cb) {
        cb('Missing permissions');
      }
    }
  };
  (0, _react.useEffect)(() => {
    const eventEmitter = new _reactNative.NativeEventEmitter(_reactNative.NativeModules.IBeacon);
    let eventListener = eventEmitter.addListener('onScanResults', event => {
      if (event.device) {
        console.log(`iBeacon data:`, event);
        setDevice(event.device);
        setTemperature(event.temperature);
        setGravity(event.gravity);
      }
    });
    return () => {
      Tilt.stopScanning();
      eventListener.remove();
    };
  }, []);
  const requestAndroidPermissions = async () => {
    const bluetoothScanPermission = await _reactNative.PermissionsAndroid.request(_reactNative.PermissionsAndroid.PERMISSIONS.BLUETOOTH_SCAN, {
      title: 'Scan Permission',
      message: 'Bluetooth Low Energy requires Scan',
      buttonPositive: 'OK'
    });
    const bluetoothConnectPermission = await _reactNative.PermissionsAndroid.request(_reactNative.PermissionsAndroid.PERMISSIONS.BLUETOOTH_CONNECT, {
      title: 'Connect Permission',
      message: 'Bluetooth Low Energy requires Connect',
      buttonPositive: 'OK'
    });
    const fineLocationPermission = await _reactNative.PermissionsAndroid.request(_reactNative.PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION, {
      title: 'Location Permission',
      message: 'Bluetooth Low Energy requires Location',
      buttonPositive: 'OK'
    });
    const coarseLocationPermission = await _reactNative.PermissionsAndroid.request(_reactNative.PermissionsAndroid.PERMISSIONS.ACCESS_COARSE_LOCATION, {
      title: 'Location Permission',
      message: 'Bluetooth Low Energy requires Coarse Location',
      buttonPositive: 'OK'
    });
    return bluetoothScanPermission === 'granted' && bluetoothConnectPermission === 'granted' && fineLocationPermission === 'granted' && coarseLocationPermission === 'granted';
  };
  const requestPermissions = async () => {
    return new Promise(async function (resolve, reject) {
      if (_reactNative.Platform.OS === 'android') {
        const allowed = await requestAndroidPermissions();
        if (!allowed) {
          return reject('Not allowed');
        }
        resolve(allowed);
      } else {
        return reject('Android only');
      }
    });
  };
  return {
    startScan,
    scanning,
    temperature,
    gravity,
    device
  };
}
//# sourceMappingURL=index.js.map